@@ -153,9 +153,10 @@ class Stream(
     def run(self):
         runners = (loop.start for loop in self.loops if loop.ready)
         asyncio.wait(asyncio.run(runners))
+        logger.debug("Stream ALL Loop Closed")
 
         if self._exit_code != 0:
-            sys.exit(self._exit_code)
+            os._exit(self._exit_code)
 
     def close(self, code=0):
         self._exit_code = code
@@ -328,6 +329,7 @@ class StreamCallLoop(StreamMQBaseLoop):
     def close(self):
         logger.debug("Stream Call Loop Closing...")
         mq.close()
+        logger.debug("Stream Call Loop Closed")
 
     @runtime.globalrun
     def start(self):
@@ -361,6 +363,7 @@ class StreamTriggerLoop(StreamMQBaseLoop):
     def close(self):
         logger.debug("Stream Trigger Loop Closing...")
         self._loop.close()
+        logger.debug("Stream Trigger Loop Closed")
 
     @runtime.globalrun
     def start(self):
@@ -382,6 +385,7 @@ class StreamSIOLoop(StreamBaseLoop):
         self.staticFiles = {}
         self._enabled = not g.serviceSioDisable
         self.server = None
+        self.web = None
 
     def _getDefaultOptions(self):
         options = Context()
@@ -476,6 +480,10 @@ class StreamSIOLoop(StreamBaseLoop):
         logger.debug("Stream SIO Loop Closing...")
         if self.server:
             self.server.close()
+        logger.debug("Stream SIO Loop Closed")
+
+    def setWebApp(self, web):
+        self.web = web
 
     def _init_win_server(self):
         p = None
@@ -508,7 +516,10 @@ class StreamSIOLoop(StreamBaseLoop):
     def start(self):
         logger.debug("Stream SIO Loop Starting...")
         self.staticFiles = self.getDefaultStaticFiles(self.staticFolder)
-        app = socketio.WSGIApp(self.sio, static_files=self.staticFiles)
+        if self.web:
+            app = self.web
+        else:
+            app = socketio.WSGIApp(self.sio, static_files=self.staticFiles)
         self.server = gevent.pywsgi.WSGIServer(
             ("", g.port), app, handler_class=WebSocketHandler
         )
@@ -547,6 +558,7 @@ class StreamHTTPLoop(StreamBaseLoop):
         logger.debug("Stream HTTP Loop Closing...")
         if self.server:
             self.server.close()
+        logger.debug("Stream HTTP Loop Closed")
 
     def _init_win_server(self):
         p = None
